@@ -12,19 +12,25 @@ def main():
     parser = optparse.OptionParser()
     parser.add_option('-i', '--interpreter', action='append',
                       help='Path to js interpreter to run on')
+    parser.add_option('-k', action='store', dest='test_name_filter',
+                      help='Only select tests matching this regular expression')
+    parser.add_option('-l', '--collect-only', action='store_true',
+                      help='Only list selected tests, do not execute')
     parser.add_option('--lib', action='append',
                       help='Add library module to test run')
     parser.add_option('--test', action='append',
                       help='Add test module to test run')
-    parser.add_option('-k', '--keep-modules', action='store_true',
+    parser.add_option('--keep-modules', action='store_true',
                       help='Keep test modules after run')
     parser.add_option('-v', '--verbose', action='store_true')
     (options, args) = parser.parse_args()
 
+    collect_only = options.collect_only
     interpreters = []
-    libs = []
-    tests = []
     keep_modules = options.keep_modules
+    libs = []
+    test_name_filter = options.test_name_filter
+    tests = []
     verbose = options.verbose
 
     if os.path.exists(CONFIG_FILE):
@@ -38,9 +44,11 @@ def main():
         tests = options.test
 
     runner = TestRunner(
+        collect_only=collect_only,
         interpreters=interpreters,
         keep_modules=keep_modules,
         libs=libs,
+        test_name_filter=test_name_filter,
         tests=tests,
         verbose=verbose,
     )
